@@ -8,7 +8,7 @@
 # - poprawic indeksowanie w show!!!!!!!!!!!!
 #- wczytywanie qimagereaderem w innym watku, na finish ustaw pixmape
 import sys
-from PySide.QtCore import QThread, QEvent, QTimer, QCoreApplication, Qt, QSize
+from PySide.QtCore import QThread, QEvent, QRect, QTimer, QCoreApplication, Qt, QSize
 from PySide import QtMaemo5
 from PySide.QtGui import QImageReader, QWidget, QImage, QMessageBox, QMenu, QPushButton, QApplication, QFileDialog, QInputDialog, QSizePolicy, QScrollArea, QIcon, QGridLayout, QAction, QPalette, QToolButton, QMainWindow, QPixmap, QLabel
 import os, md5, math
@@ -538,7 +538,8 @@ class Main(QMainWindow): ################## Main Class ##################
           print "making thumb",
           os.chdir(self.dirPix)
           self.reader.setFileName(self.licz[i])
-          self.reader.setScaledSize(QSize(182,115))
+          self.reader.setScaledSize(QSize(115,115))
+          self.reader.setClipRect(QRect(0,0,800,800))
           pixmap = QPixmap(self.reader.read())#.scaledToHeight(115)#self.licz[i])#self.reader.read()).scaledToHeight(115)
 #          pixmap.scaled(115,115)
           if pixmap.isNull():
@@ -596,7 +597,25 @@ class Main(QMainWindow): ################## Main Class ##################
           k+=1
           self.pathList[i] = self.licz[i]
         else:
-          print "null pixmap"
+          print "null pixmap", self.licz[i]
+          print "making thumb",
+          os.chdir(self.dirPix)
+          self.reader.setFileName(self.licz[i])
+          self.reader.setScaledSize(QSize(115,115))
+          self.reader.setClipRect(QRect(0,0,800,800))
+          pixmap = QPixmap(self.reader.read())#.scaledToHeight(115)#self.licz[i])#self.reader.read()).scaledToHeight(115)
+          #          pixmap.scaled(115,115)
+          if pixmap.isNull():
+            print "Unknown error while loading image"
+          self.miniatures[i] = PixBtn(self, self.licz[i], i, self.labelP)
+          self.miniatures[i].setIconSize(QSize(pixmap.width(),pixmap.height()))
+          self.miniatures[i].setIcon(QIcon(pixmap))
+          self.miniatures[i].blockSignals(True)
+          #self.miniatures[i].clicked.connect(self.showPix)
+          self.layoutPortrait.addWidget(self.miniatures[i],j,k)
+          k+=1
+          self.pathList[i] = self.licz[i]
+          os.chdir("/home/user/.thumbnails/cropped")      
         
         QApplication.processEvents()
         text = str(i+1)+"/"+str(len(self.licz))
